==> softcorp_flutter_core-1.0.33.tar.gz: lib/default_list_form/default_list_form.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_form_field/default_form_field.dart';
import '../constants.dart';

class DefaultListFormController {
  final List<String>? initialValues;
  final List<TextEditingController> textEditingControllers = [];

  DefaultListFormController({this.initialValues}) {
    if (initialValues != null) {
      for (var value in initialValues!) {
        if (value.isEmpty) {
          return;
        }
        TextEditingController textEditingController =
            TextEditingController();
        textEditingController.text = value;
        textEditingControllers.add(textEditingController);
      }
    }
    if (textEditingControllers.isEmpty || initialValues == null) {
      textEditingControllers.add(TextEditingController());
    }
  }

  List<String> getValues() {
    List<String> values = textEditingControllers.map((controller) {
      return controller.text;
    }).toList();
    values.removeWhere((value) => value.isEmpty);
    return values;
  }
}

class DefaultListForm extends StatefulWidget {
  final TextInputType textInputType;
  final DefaultListFormController controller;
  final String hint;
  final String label;

  const DefaultListForm(
      {Key? key,
      required this.textInputType,
      required this.label,
      required this.hint,
      required this.controller})
      : super(key: key);

  @override
  State<DefaultListForm> createState() {
    return _DefaultListFormState(
        hint: hint,
        label: label,
        controller: controller,
        textInputType: textInputType);
  }
}

class _DefaultListFormState extends State<DefaultListForm> {
  final TextInputType textInputType;
  final String hint;
  final String label;
  final DefaultListFormController controller;

  _DefaultListFormState(
      {required this.textInputType,
      required this.label,
      required this.hint,
      required this.controller});

  @override
  Widget build(BuildContext context) {
    return ListView.builder(
      scrollDirection: Axis.vertical,
      shrinkWrap: true,
      itemCount: controller.textEditingControllers.length,
      itemBuilder: (context, index) {
        TextEditingController textEditingController =
            controller.textEditingControllers.elementAt(index);
        return Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Expanded(
              child: DefaultFormField(
                  textEditingController: textEditingController,
                  addDefaultBorder: true,
                  textInputType: TextInputType.url,
                  hint: hint,
                  label: label),
              flex: 5,
            ),
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(top: 20),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    IconButton(
                      icon: const Icon(Icons.remove_rounded),
                      color: index == 0 ? Colors.grey : defaultDangerColor,
                      onPressed: () {
                        if (index != 0) {
                          setState(() {
                            controller.textEditingControllers.removeAt(index);
                          });
                        }
                      },
                    ),
                    const SizedBox(width: 5),
                    IconButton(
                      icon: const Icon(Icons.add_rounded),
                      color: defaultSuccessColor,
                      onPressed: () {
                        setState(() {
                          controller.textEditingControllers
                              .add(TextEditingController());
                        });
                      },
                    ),
                  ],
                ),
              ),
              flex: 2,
            ),
          ],
        );
      },
    );
  }
}

==> softcorp_flutter_core-1.0.55.tar.gz: lib/default_list_form/default_list_form.dart <==
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_form_field/default_form_field.dart';
import '../constants.dart';

class DefaultListFormController {
  final List<String>? initialValues;
  final List<TextEditingController> textEditingControllers = [];

  DefaultListFormController({this.initialValues}) {
    if (initialValues != null) {
      for (var value in initialValues!) {
        if (value.isEmpty) {
          return;
        }
        TextEditingController textEditingController = TextEditingController();
        textEditingController.text = value;
        textEditingControllers.add(textEditingController);
      }
    }
    if (textEditingControllers.isEmpty || initialValues == null) {
      textEditingControllers.add(TextEditingController());
    }
  }

  List<String> getValues() {
    List<String> values = textEditingControllers.map((controller) {
      return controller.text;
    }).toList();
    values.removeWhere((value) => value.isEmpty);
    return values;
  }
}

class DefaultListForm extends StatefulWidget {
  final TextInputType textInputType;
  final DefaultListFormController controller;
  final String hint;
  final String label;

  const DefaultListForm(
      {Key? key,
      required this.textInputType,
      required this.label,
      required this.hint,
      required this.controller})
      : super(key: key);

  @override
  State<DefaultListForm> createState() {
    return _DefaultListFormState();
  }
}

class _DefaultListFormState extends State<DefaultListForm> {
  @override
  Widget build(BuildContext context) {
    return Column(
      children:
          widget.controller.textEditingControllers.map((textEditingController) {
        var index = widget.controller.textEditingControllers
            .indexOf(textEditingController);
        return Row(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Expanded(
              child: DefaultFormField(
                  textEditingController: textEditingController,
                  addDefaultBorder: true,
                  textInputType: TextInputType.url,
                  hint: widget.hint,
                  label: widget.label),
              flex: 5,
            ),
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(top: 20),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    IconButton(
                      icon: const Icon(Icons.remove_rounded),
                      color: index == 0 ? Colors.grey : defaultDangerColor,
                      onPressed: () {
                        if (index != 0) {
                          setState(() {
                            widget.controller.textEditingControllers
                                .removeAt(index);
                          });
                        }
                      },
                    ),
                    const SizedBox(width: 5),
                    IconButton(
                      icon: const Icon(Icons.add_rounded),
                      color: defaultSuccessColor,
                      onPressed: () {
                        setState(() {
                          widget.controller.textEditingControllers
                              .add(TextEditingController());
                        });
                      },
                    ),
                  ],
                ),
              ),
              flex: 2,
            ),
          ],
        );
      }).toList(),
    );
  }
}
